@@ -1,4 +1,4 @@
-/* $Id: log-vbox.cpp 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: log-vbox.cpp 122708 2018-05-18 13:20:51Z aleksey $ */
 /** @file
  * VirtualBox Runtime - Logging configuration.
  */
@@ -352,6 +352,7 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
     ASSERT_LOG_GROUP(MAIN_CONSOLE);
     ASSERT_LOG_GROUP(MAIN_CPUCHANGEDEVENT);
     ASSERT_LOG_GROUP(MAIN_CPUEXECUTIONCAPCHANGEDEVENT);
+    ASSERT_LOG_GROUP(MAIN_CURSORPOSITIONCHANGEDEVENT);
     ASSERT_LOG_GROUP(MAIN_DHCPSERVER);
     ASSERT_LOG_GROUP(MAIN_DIRECTORY);
     ASSERT_LOG_GROUP(MAIN_DISPLAY);
@@ -748,7 +749,7 @@ RTDECL(PRTLOGGER) RTLogDefaultInit(void)
         pLogger->fDestFlags |= RTLOGDEST_DEBUGGER;
 # endif
 # if defined(DEBUG_aleksey)  /* Guest ring-0 as well */
-        RTLogGroupSettings(pLogger, "net_flt_drv.e.l.f.l3.l4.l5 +net_adp_drv.e.l.f.l3.l4.l5.l6");
+        RTLogGroupSettings(pLogger, "net_flt_drv.e.l.f.l3.l4.l5.l6 +net_adp_drv.e.l.f.l3.l4.l5.l6");
         RTLogFlags(pLogger, "enabled unbuffered");
         pLogger->fDestFlags |= RTLOGDEST_DEBUGGER | RTLOGDEST_STDOUT;
 # endif
