@@ -1,10 +1,10 @@
-/* $Id: strtonum.cpp 89632 2013-10-07 21:19:37Z bird $ */
+/* $Id: strtonum.cpp 124932 2018-09-09 13:53:25Z bird $ */
 /** @file
  * IPRT - String To Number Conversion.
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,9 +25,9 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include <iprt/string.h>
 #include "internal/iprt.h"
 
@@ -36,9 +36,9 @@
 #include <iprt/err.h>
 
 
-/*******************************************************************************
-*   Global Variables                                                           *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 /** 8-bit char -> digit. */
 static const unsigned char g_auchDigits[256] =
 {
@@ -556,7 +556,7 @@ RTDECL(int) RTStrToInt64Ex(const char *pszValue, char **ppszNext, unsigned uBase
     const char   *psz = pszValue;
     int           iShift;
     int           rc;
-    int64_t       i64;
+    uint64_t      u64;
     unsigned char uch;
 
     /*
@@ -604,31 +604,34 @@ RTDECL(int) RTStrToInt64Ex(const char *pszValue, char **ppszNext, unsigned uBase
      * Interpret the value.
      * Note: We only support ascii digits at this time... :-)
      */
-    iShift = g_auchShift[uBase]; /** @todo test this, it's probably not 100% right yet. */
+    iShift = g_auchShift[uBase];
     pszValue = psz; /* (Prefix and sign doesn't count in the digit counting.) */
     rc = VINF_SUCCESS;
-    i64 = 0;
+    u64 = 0;
     while ((uch = (unsigned char)*psz) != 0)
     {
         unsigned char chDigit = g_auchDigits[uch];
-        int64_t i64Prev;
+        uint64_t u64Prev;
 
         if (chDigit >= uBase)
             break;
 
-        i64Prev = i64;
-        i64 *= uBase;
-        i64 += chDigit;
-        if (i64Prev > i64 || (i64Prev >> iShift))
+        u64Prev = u64;
+        u64 *= uBase;
+        u64 += chDigit;
+        if (u64Prev > u64 || (u64Prev >> iShift))
             rc = VWRN_NUMBER_TOO_BIG;
         psz++;
     }
 
-    if (!fPositive)
-        i64 = -i64;
+    if (   !(u64 & RT_BIT_64(63))
+        || (!fPositive && u64 == RT_BIT_64(63)) )
+    { /* likely */ }
+    else
+        rc = VWRN_NUMBER_TOO_BIG;
 
     if (pi64)
-        *pi64 = i64;
+        *pi64 = fPositive ? u64 : -(int64_t)u64;
 
     if (psz == pszValue)
         rc = VERR_NO_DIGITS;
