@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 2006-2013 Oracle Corporation
+ * Copyright (C) 2006-2018 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -36,7 +36,7 @@
 #include <iprt/log.h>
 
 
-/** @defgroup grp_rt_vbox_log    VirtualBox Logging
+/** @defgroup grp_rt_vbox_log    VBox Logging
  * @ingroup grp_rt_vbox
  * @{
  */
@@ -59,6 +59,10 @@ typedef enum LOGGROUP
 {
     /** The default VBox group. */
     LOG_GROUP_DEFAULT = RTLOGGROUP_FIRST_USER,
+    /** Audio mixer group. */
+    LOG_GROUP_AUDIO_MIXER,
+    /** Audio mixer buffer group. */
+    LOG_GROUP_AUDIO_MIXER_BUFFER,
     /** Auto-logon group. */
     LOG_GROUP_AUTOLOGON,
     /** CFGM group. */
@@ -77,14 +81,14 @@ typedef enum LOGGROUP
     LOG_GROUP_DBGG,
     /** Generic Device group. */
     LOG_GROUP_DEV,
+    /** AC97 Device group. */
+    LOG_GROUP_DEV_AC97,
     /** ACPI Device group. */
     LOG_GROUP_DEV_ACPI,
     /** AHCI Device group. */
     LOG_GROUP_DEV_AHCI,
     /** APIC Device group. */
     LOG_GROUP_DEV_APIC,
-    /** Audio Device group. */
-    LOG_GROUP_DEV_AUDIO,
     /** BusLogic SCSI host adapter group. */
     LOG_GROUP_DEV_BUSLOGIC,
     /** DMA Controller group. */
@@ -93,12 +97,24 @@ typedef enum LOGGROUP
     LOG_GROUP_DEV_E1000,
     /** Extensible Firmware Interface Device group. */
     LOG_GROUP_DEV_EFI,
+    /** USB EHCI Device group. */
+    LOG_GROUP_DEV_EHCI,
     /** Floppy Controller Device group. */
     LOG_GROUP_DEV_FDC,
+    /** Flash Device group. */
+    LOG_GROUP_DEV_FLASH,
+    /** Guest Interface Manager Device group. */
+    LOG_GROUP_DEV_GIM,
+    /** HDA Device group. */
+    LOG_GROUP_DEV_HDA,
+    /** HDA Codec Device group. */
+    LOG_GROUP_DEV_HDA_CODEC,
     /** High Precision Event Timer Device group. */
     LOG_GROUP_DEV_HPET,
     /** IDE Device group. */
     LOG_GROUP_DEV_IDE,
+    /** I/O APIC Device group. */
+    LOG_GROUP_DEV_IOAPIC,
     /** The internal networking IP stack Device group. */
     LOG_GROUP_DEV_INIP,
     /** KeyBoard Controller Device group. */
@@ -107,8 +123,10 @@ typedef enum LOGGROUP
     LOG_GROUP_DEV_LPC,
     /** LsiLogic SCSI controller Device group. */
     LOG_GROUP_DEV_LSILOGICSCSI,
-    /** NE2000 Device group. */
-    LOG_GROUP_DEV_NE2000,
+    /** NVMe Device group. */
+    LOG_GROUP_DEV_NVME,
+    /** USB OHCI Device group. */
+    LOG_GROUP_DEV_OHCI,
     /** Parallel Device group */
     LOG_GROUP_DEV_PARALLEL,
     /** PC Device group. */
@@ -129,12 +147,12 @@ typedef enum LOGGROUP
     LOG_GROUP_DEV_PIT,
     /** RTC Device group. */
     LOG_GROUP_DEV_RTC,
+    /** SB16 Device group. */
+    LOG_GROUP_DEV_SB16,
     /** Serial Device group */
     LOG_GROUP_DEV_SERIAL,
     /** System Management Controller Device group. */
     LOG_GROUP_DEV_SMC,
-    /** USB Device group. */
-    LOG_GROUP_DEV_USB,
     /** VGA Device group. */
     LOG_GROUP_DEV_VGA,
     /** Virtio PCI Device group. */
@@ -147,12 +165,18 @@ typedef enum LOGGROUP
     LOG_GROUP_DEV_VMM_BACKDOOR,
     /** VMM Device group for logging guest backdoor logging to stderr. */
     LOG_GROUP_DEV_VMM_STDERR,
+    /** VMSVGA Device group. */
+    LOG_GROUP_DEV_VMSVGA,
+    /** USB xHCI Device group. */
+    LOG_GROUP_DEV_XHCI,
     /** Disassembler group. */
     LOG_GROUP_DIS,
     /** Generic driver group. */
     LOG_GROUP_DRV,
     /** ACPI driver group */
     LOG_GROUP_DRV_ACPI,
+    /** Audio driver group */
+    LOG_GROUP_DRV_AUDIO,
     /** Block driver group. */
     LOG_GROUP_DRV_BLOCK,
     /** Char driver group. */
@@ -163,6 +187,8 @@ typedef enum LOGGROUP
     LOG_GROUP_DRV_DISPLAY,
     /** Floppy media driver group. */
     LOG_GROUP_DRV_FLOPPY,
+    /** Host Audio driver group. */
+    LOG_GROUP_DRV_HOST_AUDIO,
     /** Host Base block driver group. */
     LOG_GROUP_DRV_HOST_BASE,
     /** Host DVD block driver group. */
@@ -197,10 +223,14 @@ typedef enum LOGGROUP
     LOG_GROUP_DRV_SCSI,
     /** Host SCSI driver group. */
     LOG_GROUP_DRV_SCSIHOST,
+    /** TCP socket stream driver group. */
+    LOG_GROUP_DRV_TCP,
     /** Async transport driver group */
     LOG_GROUP_DRV_TRANSPORT_ASYNC,
     /** TUN network transport driver group */
     LOG_GROUP_DRV_TUN,
+    /** UDP socket stream driver group. */
+    LOG_GROUP_DRV_UDP,
     /** UDP tunnet network transport driver group. */
     LOG_GROUP_DRV_UDPTUNNEL,
     /** USB Proxy driver group. */
@@ -209,6 +239,8 @@ typedef enum LOGGROUP
     LOG_GROUP_DRV_VBOXHDD,
     /** VBox HDD container media driver group. */
     LOG_GROUP_DRV_VD,
+    /** VRDE audio driver group. */
+    LOG_GROUP_DRV_VRDE_AUDIO,
     /** Virtual Switch transport driver group */
     LOG_GROUP_DRV_VSWITCH,
     /** VUSB driver group */
@@ -217,10 +249,14 @@ typedef enum LOGGROUP
     LOG_GROUP_EM,
     /** FTM group. */
     LOG_GROUP_FTM,
+    /** GIM group. */
+    LOG_GROUP_GIM,
     /** GMM group. */
     LOG_GROUP_GMM,
     /** Guest control. */
     LOG_GROUP_GUEST_CONTROL,
+    /** Guest drag'n drop. */
+    LOG_GROUP_GUEST_DND,
     /** GUI group. */
     LOG_GROUP_GUI,
     /** GVMM group. */
@@ -233,10 +269,70 @@ typedef enum LOGGROUP
     LOG_GROUP_HM,
     /** IEM group. */
     LOG_GROUP_IEM,
+    /** I/O buffer management group. */
+    LOG_GROUP_IOBUFMGMT,
     /** IOM group. */
     LOG_GROUP_IOM,
     /** XPCOM IPC group. */
     LOG_GROUP_IPC,
+    /** lwIP group. */
+    LOG_GROUP_LWIP,
+    /** lwIP group, api_lib.c API_LIB_DEBUG */
+    LOG_GROUP_LWIP_API_LIB,
+    /** lwIP group, api_msg.c API_MSG_DEBUG */
+    LOG_GROUP_LWIP_API_MSG,
+    /** lwIP group, etharp.c ETHARP_DEBUG */
+    LOG_GROUP_LWIP_ETHARP,
+    /** lwIP group, icmp.c ICMP_DEBUG */
+    LOG_GROUP_LWIP_ICMP,
+    /** lwIP group, igmp.c IGMP_DEBUG */
+    LOG_GROUP_LWIP_IGMP,
+    /** lwIP group, inet.c INET_DEBUG */
+    LOG_GROUP_LWIP_INET,
+    /** lwIP group, IP_DEBUG (sic!) */
+    LOG_GROUP_LWIP_IP4,
+    /** lwIP group, ip_frag.c IP_REASS_DEBUG (sic!) */
+    LOG_GROUP_LWIP_IP4_REASS,
+    /** lwIP group, IP6_DEBUG */
+    LOG_GROUP_LWIP_IP6,
+    /** lwIP group, mem.c MEM_DEBUG */
+    LOG_GROUP_LWIP_MEM,
+    /** lwIP group, memp.c MEMP_DEBUG */
+    LOG_GROUP_LWIP_MEMP,
+    /** lwIP group, netif.c NETIF_DEBUG */
+    LOG_GROUP_LWIP_NETIF,
+    /** lwIP group, pbuf.c PBUF_DEBUG */
+    LOG_GROUP_LWIP_PBUF,
+    /** lwIP group, raw.c RAW_DEBUG */
+    LOG_GROUP_LWIP_RAW,
+    /** lwIP group, sockets.c SOCKETS_DEBUG */
+    LOG_GROUP_LWIP_SOCKETS,
+    /** lwIP group, SYS_DEBUG */
+    LOG_GROUP_LWIP_SYS,
+    /** lwIP group, TCP_DEBUG */
+    LOG_GROUP_LWIP_TCP,
+    /** lwIP group, tcpip.c TCPIP_DEBUG */
+    LOG_GROUP_LWIP_TCPIP,
+    /** lwIP group, TCP_CWND_DEBUG (congestion window) */
+    LOG_GROUP_LWIP_TCP_CWND,
+    /** lwIP group, tcp_in.c TCP_FR_DEBUG (fast retransmit) */
+    LOG_GROUP_LWIP_TCP_FR,
+    /** lwIP group, tcp_in.c TCP_INPUT_DEBUG */
+    LOG_GROUP_LWIP_TCP_INPUT,
+    /** lwIP group, tcp_out.c TCP_OUTPUT_DEBUG */
+    LOG_GROUP_LWIP_TCP_OUTPUT,
+    /** lwIP group, TCP_QLEN_DEBUG */
+    LOG_GROUP_LWIP_TCP_QLEN,
+    /** lwIP group, TCP_RST_DEBUG */
+    LOG_GROUP_LWIP_TCP_RST,
+    /** lwIP group, TCP_RTO_DEBUG (retransmit) */
+    LOG_GROUP_LWIP_TCP_RTO,
+    /** lwIP group, tcp_in.c TCP_WND_DEBUG (window updates) */
+    LOG_GROUP_LWIP_TCP_WND,
+    /** lwIP group, timers.c TIMERS_DEBUG */
+    LOG_GROUP_LWIP_TIMERS,
+    /** lwIP group, udp.c UDP_DEBUG */
+    LOG_GROUP_LWIP_UDP,
     /** Main group. */
     LOG_GROUP_MAIN,
     /** Main group, IAdditionsFacility. */
@@ -247,6 +343,8 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_APPLIANCE,
     /** Main group, IAudioAdapter. */
     LOG_GROUP_MAIN_AUDIOADAPTER,
+    /** Main group, IAudioAdapterChangedEvent. */
+    LOG_GROUP_MAIN_AUDIOADAPTERCHANGEDEVENT,
     /** Main group, IBandwidthControl. */
     LOG_GROUP_MAIN_BANDWIDTHCONTROL,
     /** Main group, IBandwidthGroup. */
@@ -257,22 +355,46 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_BIOSSETTINGS,
     /** Main group, ICanShowWindowEvent. */
     LOG_GROUP_MAIN_CANSHOWWINDOWEVENT,
+    /** Main group, ICertificate. */
+    LOG_GROUP_MAIN_CERTIFICATE,
     /** Main group, IClipboardModeChangedEvent. */
     LOG_GROUP_MAIN_CLIPBOARDMODECHANGEDEVENT,
+    /** Main group, ICloudClient. */
+    LOG_GROUP_MAIN_CLOUDCLIENT,
+    /** Main group, ICloudProfile. */
+    LOG_GROUP_MAIN_CLOUDPROFILE,
+    /** Main group, ICloudProvider. */
+    LOG_GROUP_MAIN_CLOUDPROVIDER,
+    /** Main group, ICloudProviderManager. */
+    LOG_GROUP_MAIN_CLOUDPROVIDERMANAGER,
     /** Main group, IConsole. */
     LOG_GROUP_MAIN_CONSOLE,
     /** Main group, ICPUChangedEvent. */
     LOG_GROUP_MAIN_CPUCHANGEDEVENT,
     /** Main group, ICPUExecutionCapChangedEvent. */
     LOG_GROUP_MAIN_CPUEXECUTIONCAPCHANGEDEVENT,
+    /** Main group, ICursorPositionChangedEvent. */
+    LOG_GROUP_MAIN_CURSORPOSITIONCHANGEDEVENT,
+    /** Main group, IDataModel. */
+    LOG_GROUP_MAIN_DATAMODEL,
+    /** Main group, IDataStream. */
+    LOG_GROUP_MAIN_DATASTREAM,
     /** Main group, IDHCPServer. */
     LOG_GROUP_MAIN_DHCPSERVER,
     /** Main group, IDirectory. */
     LOG_GROUP_MAIN_DIRECTORY,
     /** Main group, IDisplay. */
     LOG_GROUP_MAIN_DISPLAY,
-    /** Main group, IDragAndDropModeChangedEvent. */
-    LOG_GROUP_MAIN_DRAGANDDROPMODECHANGEDEVENT,
+    /** Main group, IDisplaySourceBitmap. */
+    LOG_GROUP_MAIN_DISPLAYSOURCEBITMAP,
+    /** Main group, IDnDBase. */
+    LOG_GROUP_MAIN_DNDBASE,
+    /** Main group, IDnDModeChangedEvent. */
+    LOG_GROUP_MAIN_DNDMODECHANGEDEVENT,
+    /** Main group, IDnDSource. */
+    LOG_GROUP_MAIN_DNDSOURCE,
+    /** Main group, IDnDTarget. */
+    LOG_GROUP_MAIN_DNDTARGET,
     /** Main group, IEmulatedUSB. */
     LOG_GROUP_MAIN_EMULATEDUSB,
     /** Main group, IEvent. */
@@ -309,6 +431,10 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_GUEST,
     /** Main group, IGuestDirectory. */
     LOG_GROUP_MAIN_GUESTDIRECTORY,
+    /** Main group, IGuestDnDSource. */
+    LOG_GROUP_MAIN_GUESTDNDSOURCE,
+    /** Main group, IGuestDnDTarget. */
+    LOG_GROUP_MAIN_GUESTDNDTARGET,
     /** Main group, IGuestErrorInfo. */
     LOG_GROUP_MAIN_GUESTERRORINFO,
     /** Main group, IGuestFile. */
@@ -355,6 +481,8 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_GUESTPROCESSSTATECHANGEDEVENT,
     /** Main group, IGuestPropertyChangedEvent. */
     LOG_GROUP_MAIN_GUESTPROPERTYCHANGEDEVENT,
+    /** Main group, IGuestScreenInfo. */
+    LOG_GROUP_MAIN_GUESTSCREENINFO,
     /** Main group, IGuestSession. */
     LOG_GROUP_MAIN_GUESTSESSION,
     /** Main group, IGuestSessionEvent. */
@@ -405,14 +533,20 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_MEDIUMATTACHMENT,
     /** Main group, IMediumChangedEvent. */
     LOG_GROUP_MAIN_MEDIUMCHANGEDEVENT,
+    /** Main group, IMediumConfigChangedEvent. */
+    LOG_GROUP_MAIN_MEDIUMCONFIGCHANGEDEVENT,
     /** Main group, IMediumFormat. */
     LOG_GROUP_MAIN_MEDIUMFORMAT,
+    /** Main group, IMediumIO. */
+    LOG_GROUP_MAIN_MEDIUMIO,
     /** Main group, IMediumRegisteredEvent. */
     LOG_GROUP_MAIN_MEDIUMREGISTEREDEVENT,
     /** Main group, IMouse. */
     LOG_GROUP_MAIN_MOUSE,
     /** Main group, IMouseCapabilityChangedEvent. */
     LOG_GROUP_MAIN_MOUSECAPABILITYCHANGEDEVENT,
+    /** Main group, IMousePointerShape. */
+    LOG_GROUP_MAIN_MOUSEPOINTERSHAPE,
     /** Main group, IMousePointerShapeChangedEvent. */
     LOG_GROUP_MAIN_MOUSEPOINTERSHAPECHANGEDEVENT,
     /** Main group, INATEngine. */
@@ -453,6 +587,18 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_PROCESS,
     /** Main group, IProgress. */
     LOG_GROUP_MAIN_PROGRESS,
+    /** Main group, IProgressEvent. */
+    LOG_GROUP_MAIN_PROGRESSEVENT,
+    /** Main group, IProgressPercentageChangedEvent. */
+    LOG_GROUP_MAIN_PROGRESSPERCENTAGECHANGEDEVENT,
+    /** Main group, IProgressTaskCompletedEvent. */
+    LOG_GROUP_MAIN_PROGRESSTASKCOMPLETEDEVENT,
+    /** Main group, IRecordingChangedEvent. */
+    LOG_GROUP_MAIN_RECORDINGCHANGEDEVENT,
+    /** Main group, IRecordingSettings. */
+    LOG_GROUP_MAIN_RECORDINGSETTINGS,
+    /** Main group, IRecordingScreenSettings. */
+    LOG_GROUP_MAIN_RECORDINGSCREENSETTINGS,
     /** Main group, IReusableEvent. */
     LOG_GROUP_MAIN_REUSABLEEVENT,
     /** Main group, IRuntimeErrorEvent. */
@@ -480,6 +626,8 @@ typedef enum LOGGROUP
     /** Main group, ISnapshotEvent. */
     LOG_GROUP_MAIN_SNAPSHOTEVENT,
     /** Main group, ISnapshotTakenEvent. */
+    LOG_GROUP_MAIN_SNAPSHOTRESTOREDEVENT,
+    /** Main group, ISnapshotRestoredEvent. */
     LOG_GROUP_MAIN_SNAPSHOTTAKENEVENT,
     /** Main group, IStateChangedEvent. */
     LOG_GROUP_MAIN_STATECHANGEDEVENT,
@@ -491,8 +639,12 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_STORAGEDEVICECHANGEDEVENT,
     /** Main group, ISystemProperties. */
     LOG_GROUP_MAIN_SYSTEMPROPERTIES,
+    /** Main group, threaded tasks. */
+    LOG_GROUP_MAIN_THREAD_TASK,
     /** Main group, IToken. */
     LOG_GROUP_MAIN_TOKEN,
+    /** Main group, IUnattended. */
+    LOG_GROUP_MAIN_UNATTENDED,
     /** Main group, IUSBController. */
     LOG_GROUP_MAIN_USBCONTROLLER,
     /** Main group, IUSBControllerChangedEvent. */
@@ -505,20 +657,26 @@ typedef enum LOGGROUP
     LOG_GROUP_MAIN_USBDEVICEFILTERS,
     /** Main group, IUSBDeviceStateChangedEvent. */
     LOG_GROUP_MAIN_USBDEVICESTATECHANGEDEVENT,
+    /** Main group, IUSBProxyBackend. */
+    LOG_GROUP_MAIN_USBPROXYBACKEND,
+    /** Main group, IVBoxSVC. */
+    LOG_GROUP_MAIN_VBOXSVC,
     /** Main group, IVBoxSVCAvailabilityChangedEvent. */
     LOG_GROUP_MAIN_VBOXSVCAVAILABILITYCHANGEDEVENT,
     /** Main group, IVetoEvent. */
     LOG_GROUP_MAIN_VETOEVENT,
     /** Main group, IVFSExplorer. */
     LOG_GROUP_MAIN_VFSEXPLORER,
-    /** Main group, IVideoCaptureChangedEvent. */
-    LOG_GROUP_MAIN_VIDEOCAPTURECHANGEDEVENT,
     /** Main group, IVirtualBox. */
     LOG_GROUP_MAIN_VIRTUALBOX,
     /** Main group, IVirtualBoxClient. */
     LOG_GROUP_MAIN_VIRTUALBOXCLIENT,
+    /** Main group, IVirtualBoxSDS. */
+    LOG_GROUP_MAIN_VIRTUALBOXSDS,
     /** Main group, IVirtualSystemDescription. */
     LOG_GROUP_MAIN_VIRTUALSYSTEMDESCRIPTION,
+    /** Main group, VMM device interfaces. */
+    LOG_GROUP_MAIN_VMMDEVINTERFACES,
     /** Main group, IVRDEServer. */
     LOG_GROUP_MAIN_VRDESERVER,
     /** Main group, IVRDEServerChangedEvent. */
@@ -543,6 +701,8 @@ typedef enum LOGGROUP
     LOG_GROUP_MM_POOL,
     /** The NAT service group */
     LOG_GROUP_NAT_SERVICE,
+    /** NEM group. */
+    LOG_GROUP_NEM,
     /** The network adaptor driver group. */
     LOG_GROUP_NET_ADP_DRV,
     /** The network filter driver group. */
@@ -629,14 +789,18 @@ typedef enum LOGGROUP
     LOG_GROUP_USB_MOUSE,
     /** MSD USB device group. */
     LOG_GROUP_USB_MSD,
+    /** USB remote support. */
+    LOG_GROUP_USB_REMOTE,
     /** USB webcam. */
     LOG_GROUP_USB_WEBCAM,
     /** VBox Guest Additions Driver (VBoxGuest). */
-    LOG_GROUP_VBGD,
+    LOG_GROUP_VGDRV,
     /** VBox Guest Additions Library. */
     LOG_GROUP_VBGL,
     /** Generic virtual disk layer. */
     LOG_GROUP_VD,
+    /** CUE/BIN virtual disk backend. */
+    LOG_GROUP_VD_CUE,
     /** DMG virtual disk backend. */
     LOG_GROUP_VD_DMG,
     /** iSCSI virtual disk backend. */
@@ -653,6 +817,8 @@ typedef enum LOGGROUP
     LOG_GROUP_VD_VDI,
     /** VHD virtual disk backend. */
     LOG_GROUP_VD_VHD,
+    /** VHDX virtual disk backend. */
+    LOG_GROUP_VD_VHDX,
     /** VMDK virtual disk backend. */
     LOG_GROUP_VD_VMDK,
     /** VM group. */
@@ -688,6 +854,8 @@ typedef enum LOGGROUP
 {                   \
     RT_LOGGROUP_NAMES, \
     "DEFAULT",      \
+    "AUDIO_MIXER",  \
+    "AUDIO_MIXER_BUFFER", \
     "AUTOLOGON",    \
     "CFGM",         \
     "CPUM",         \
@@ -697,22 +865,29 @@ typedef enum LOGGROUP
     "DBGF_INFO",    \
     "DBGG",         \
     "DEV",          \
+    "DEV_AC97",     \
     "DEV_ACPI",     \
     "DEV_AHCI",     \
     "DEV_APIC",     \
-    "DEV_AUDIO",    \
     "DEV_BUSLOGIC", \
     "DEV_DMA",      \
     "DEV_E1000",    \
     "DEV_EFI",      \
+    "DEV_EHCI",     \
     "DEV_FDC",      \
+    "DEV_FLASH",    \
+    "DEV_GIM",      \
+    "DEV_HDA",      \
+    "DEV_HDA_CODEC", \
     "DEV_HPET",     \
     "DEV_IDE",      \
+    "DEV_IOAPIC",   \
     "DEV_INIP",     \
     "DEV_KBD",      \
     "DEV_LPC",      \
     "DEV_LSILOGICSCSI", \
-    "DEV_NE2000",   \
+    "DEV_NVME",     \
+    "DEV_OHCI",     \
     "DEV_PARALLEL", \
     "DEV_PC",       \
     "DEV_PC_ARCH",  \
@@ -723,23 +898,27 @@ typedef enum LOGGROUP
     "DEV_PIC",      \
     "DEV_PIT",      \
     "DEV_RTC",      \
+    "DEV_SB16",     \
     "DEV_SERIAL",   \
     "DEV_SMC",      \
-    "DEV_USB",      \
     "DEV_VGA",      \
     "DEV_VIRTIO",   \
     "DEV_VIRTIO_NET", \
     "DEV_VMM",      \
     "DEV_VMM_BACKDOOR", \
     "DEV_VMM_STDERR", \
+    "DEV_VMSVGA",   \
+    "DEV_XHCI",     \
     "DIS",          \
     "DRV",          \
     "DRV_ACPI",     \
+    "DRV_AUDIO",    \
     "DRV_BLOCK",    \
     "DRV_CHAR",     \
     "DRV_DISK_INTEGRITY", \
     "DRV_DISPLAY",  \
     "DRV_FLOPPY",   \
+    "DRV_HOST_AUDIO", \
     "DRV_HOST_BASE", \
     "DRV_HOST_DVD", \
     "DRV_HOST_FLOPPY", \
@@ -757,44 +936,92 @@ typedef enum LOGGROUP
     "DRV_RAW_IMAGE", \
     "DRV_SCSI",     \
     "DRV_SCSIHOST", \
+    "DRV_TCP", \
     "DRV_TRANSPORT_ASYNC", \
     "DRV_TUN",      \
+    "DRV_UDP", \
     "DRV_UDPTUNNEL", \
     "DRV_USBPROXY", \
     "DRV_VBOXHDD",  \
     "DRV_VD",       \
+    "DRV_VRDE_AUDIO", \
     "DRV_VSWITCH",  \
     "DRV_VUSB",     \
     "EM",           \
     "FTM",          \
+    "GIM",          \
     "GMM",          \
     "GUEST_CONTROL", \
+    "GUEST_DND",    \
     "GUI",          \
     "GVMM",         \
     "HGCM",         \
     "HGSMI",        \
     "HM",           \
     "IEM",          \
+    "IOBUFMGMT",    \
     "IOM",          \
     "IPC",          \
+    "LWIP",            \
+    "LWIP_API_LIB",    \
+    "LWIP_API_MSG",    \
+    "LWIP_ETHARP",     \
+    "LWIP_ICMP",       \
+    "LWIP_IGMP",       \
+    "LWIP_INET",       \
+    "LWIP_IP4",        \
+    "LWIP_IP4_REASS",  \
+    "LWIP_IP6",        \
+    "LWIP_MEM",        \
+    "LWIP_MEMP",       \
+    "LWIP_NETIF",      \
+    "LWIP_PBUF",       \
+    "LWIP_RAW",        \
+    "LWIP_SOCKETS",    \
+    "LWIP_SYS",        \
+    "LWIP_TCP",        \
+    "LWIP_TCPIP",      \
+    "LWIP_TCP_CWND",   \
+    "LWIP_TCP_FR",     \
+    "LWIP_TCP_INPUT",  \
+    "LWIP_TCP_OUTPUT", \
+    "LWIP_TCP_QLEN",   \
+    "LWIP_TCP_RST",    \
+    "LWIP_TCP_RTO",    \
+    "LWIP_TCP_WND",    \
+    "LWIP_TIMERS",     \
+    "LWIP_UDP",        \
     "MAIN",         \
     "MAIN_ADDITIONSFACILITY", \
     "MAIN_ADDITIONSSTATECHANGEDEVENT", \
     "MAIN_APPLIANCE", \
     "MAIN_AUDIOADAPTER", \
+    "MAIN_AUDIOADAPTERCHANGEDEVENT", \
     "MAIN_BANDWIDTHCONTROL", \
     "MAIN_BANDWIDTHGROUP", \
     "MAIN_BANDWIDTHGROUPCHANGEDEVENT", \
     "MAIN_BIOSSETTINGS", \
     "MAIN_CANSHOWWINDOWEVENT", \
+    "MAIN_CERTIFICATE", \
     "MAIN_CLIPBOARDMODECHANGEDEVENT", \
+    "MAIN_CLOUDCLIENT", \
+    "MAIN_CLOUDPROFILE", \
+    "MAIN_CLOUDPROVIDER", \
+    "MAIN_CLOUDPROVIDERMANAGER", \
     "MAIN_CONSOLE", \
     "MAIN_CPUCHANGEDEVENT", \
     "MAIN_CPUEXECUTIONCAPCHANGEDEVENT", \
+    "MAIN_CURSORPOSITIONCHANGEDEVENT", \
+    "MAIN_DATAMODEL", \
+    "MAIN_DATASTREASTREAM", \
     "MAIN_DHCPSERVER", \
     "MAIN_DIRECTORY", \
     "MAIN_DISPLAY", \
-    "MAIN_DRAGANDDROPMODECHANGEDEVENT", \
+    "MAIN_DISPLAYSOURCEBITMAP", \
+    "MAIN_DNDBASE", \
+    "MAIN_DNDMODECHANGEDEVENT", \
+    "MAIN_DNDSOURCE", \
+    "MAIN_DNDTARGET", \
     "MAIN_EMULATEDUSB",   \
     "MAIN_EVENT",   \
     "MAIN_EVENTLISTENER", \
@@ -813,6 +1040,8 @@ typedef enum LOGGROUP
     "MAIN_FSOBJINFO", \
     "MAIN_GUEST",   \
     "MAIN_GUESTDIRECTORY", \
+    "MAIN_GUESTDNDSOURCE", \
+    "MAIN_GUESTDNDTARGET", \
     "MAIN_GUESTERRORINFO", \
     "MAIN_GUESTFILE", \
     "MAIN_GUESTFILEEVENT", \
@@ -836,6 +1065,7 @@ typedef enum LOGGROUP
     "MAIN_GUESTPROCESSREGISTEREDEVENT", \
     "MAIN_GUESTPROCESSSTATECHANGEDEVENT", \
     "MAIN_GUESTPROPERTYCHANGEDEVENT", \
+    "MAIN_GUESTSCREENINFO", \
     "MAIN_GUESTSESSION", \
     "MAIN_GUESTSESSIONEVENT", \
     "MAIN_GUESTSESSIONREGISTEREDEVENT", \
@@ -861,10 +1091,13 @@ typedef enum LOGGROUP
     "MAIN_MEDIUM",  \
     "MAIN_MEDIUMATTACHMENT", \
     "MAIN_MEDIUMCHANGEDEVENT", \
+    "MAIN_MEDIUMCONFIGCHANGEDEVENT", \
     "MAIN_MEDIUMFORMAT", \
+    "MAIN_MEDIUMIO", \
     "MAIN_MEDIUMREGISTEREDEVENT", \
     "MAIN_MOUSE",   \
     "MAIN_MOUSECAPABILITYCHANGEDEVENT", \
+    "MAIN_MOUSEPOINTERSHAPE", \
     "MAIN_MOUSEPOINTERSHAPECHANGEDEVENT", \
     "MAIN_NATENGINE", \
     "MAIN_NATNETWORK", \
@@ -885,6 +1118,12 @@ typedef enum LOGGROUP
     "MAIN_PERFORMANCEMETRIC", \
     "MAIN_PROCESS", \
     "MAIN_PROGRESS", \
+    "MAIN_PROGRESSEVENT", \
+    "MAIN_PROGRESSPERCENTAGECHANGEDEVENT", \
+    "MAIN_PROGRESSTASKCOMPLETEDEVENT", \
+    "MAIN_RECORDINGCHANGEDEVENT", \
+    "MAIN_RECORDINGSETTINGS", \
+    "MAIN_RECORDINGSCREENSETTINGS", \
     "MAIN_REUSABLEEVENT", \
     "MAIN_RUNTIMEERROREVENT", \
     "MAIN_SERIALPORT", \
@@ -898,26 +1137,32 @@ typedef enum LOGGROUP
     "MAIN_SNAPSHOTCHANGEDEVENT", \
     "MAIN_SNAPSHOTDELETEDEVENT", \
     "MAIN_SNAPSHOTEVENT", \
+    "MAIN_SNAPSHOTRESTOREDEVENT", \
     "MAIN_SNAPSHOTTAKENEVENT", \
     "MAIN_STATECHANGEDEVENT", \
     "MAIN_STORAGECONTROLLER", \
     "MAIN_STORAGECONTROLLERCHANGEDEVENT", \
     "MAIN_STORAGEDEVICECHANGEDEVENT", \
     "MAIN_SYSTEMPROPERTIES", \
+    "MAIN_THREAD_TASK", \
     "MAIN_TOKEN", \
+    "MAIN_UNATTENDED", \
     "MAIN_USBCONTROLLER", \
     "MAIN_USBCONTROLLERCHANGEDEVENT", \
     "MAIN_USBDEVICE", \
     "MAIN_USBDEVICEFILTER", \
     "MAIN_USBDEVICEFILTERS", \
     "MAIN_USBDEVICESTATECHANGEDEVENT", \
+    "MAIN_USBPROXYBACKEND", \
+    "MAIN_VBOXSVC", \
     "MAIN_VBOXSVCAVAILABILITYCHANGEDEVENT", \
     "MAIN_VETOEVENT", \
     "MAIN_VFSEXPLORER", \
-    "MAIN_VIDEOCAPTURECHANGEDEVENT", \
     "MAIN_VIRTUALBOX", \
     "MAIN_VIRTUALBOXCLIENT", \
+    "MAIN_VIRTUALBOXSDS", \
     "MAIN_VIRTUALSYSTEMDESCRIPTION", \
+    "MAIN_VMMDEVINTERFACES", \
     "MAIN_VRDESERVER", \
     "MAIN_VRDESERVERCHANGEDEVENT", \
     "MAIN_VRDESERVERINFO", \
@@ -930,6 +1175,7 @@ typedef enum LOGGROUP
     "MM_PHYS",      \
     "MM_POOL",      \
     "NAT_SERVICE",  \
+    "NEM",          \
     "NET_ADP_DRV",  \
     "NET_FLT_DRV",  \
     "NET_SERVICE",  \
@@ -973,10 +1219,12 @@ typedef enum LOGGROUP
     "USB_KBD",      \
     "USB_MOUSE",    \
     "USB_MSD",      \
+    "USB_REMOTE",   \
     "USB_WEBCAM",   \
-    "VBGD",         \
+    "VGDRV",        \
     "VBGL",         \
     "VD",           \
+    "VD_CUE",       \
     "VD_DMG",       \
     "VD_ISCSI",     \
     "VD_PARALLELS", \
@@ -985,6 +1233,7 @@ typedef enum LOGGROUP
     "VD_RAW",       \
     "VD_VDI",       \
     "VD_VHD",       \
+    "VD_VHDX",      \
     "VD_VMDK",      \
     "VM",           \
     "VMM",          \
