@@ -1,4 +1,4 @@
-/* $Id: time.h 118810 2017-10-28 13:12:06Z bird $ */
+/* $Id: time.h 123408 2018-07-04 10:13:40Z bird $ */
 /** @file
  * IPRT - Internal RTTime header
  */
@@ -34,8 +34,6 @@ RT_C_DECLS_BEGIN
 #if defined(IN_RING3) || defined(IN_RC)
 
 extern DECLHIDDEN(uint64_t) g_u64ProgramStartNanoTS;
-extern DECLHIDDEN(uint64_t) g_u64ProgramStartMicroTS;
-extern DECLHIDDEN(uint64_t) g_u64ProgramStartMilliTS;
 
 #endif
 
