@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 2008-2013 Oracle Corporation
+ * Copyright (C) 2008-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -38,6 +38,19 @@ RT_C_DECLS_BEGIN
  * @{
  */
 
+/**
+ * Converts an stringified Ethernet MAC address into the RTMAC representation.
+ *
+ * @todo This should be move to some generic part of the runtime.
+ *
+ * @returns VINF_SUCCESS on success, VERR_GETOPT_INVALID_ARGUMENT_FORMAT on
+ *          failure.
+ *
+ * @param   pszAddr         The address string to convert.
+ * @param   pMacAddr        Where to store the result.
+ */
+RTDECL(int) RTNetStrToMacAddr(const char *pszAddr, PRTMAC pMacAddr);
+
 /**
  * IPv4 address.
  */
@@ -52,20 +65,80 @@ typedef RTNETADDRIPV4 const *PCRTNETADDRIPV4;
  * Tests if the given string is an IPv4 address.
  *
  * @returns boolean.
- * @param   pszAddress          String which may be an IPv4 address.
+ * @param   pcszAddr        String which may be an IPv4 address.
  */
-RTDECL(bool) RTNetIsIPv4AddrStr(const char *pszAddress);
+RTDECL(bool) RTNetIsIPv4AddrStr(const char *pcszAddr);
 
 /**
- * Converts an stringified IPv4 address into the RTNETADDRIPV4 representation.
+ * Tests if the given string is a wildcard IPv4 address.
+ *
+ * @returns boolean.
+ * @param   pcszAddr        String which may be an IPv4 address.
+ */
+RTDECL(bool) RTNetStrIsIPv4AddrAny(const char *pcszAddr);
+
+/**
+ * Parses dotted-decimal IPv4 address into RTNETADDRIPV4 representation.
  *
  * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
  *          failure.
  *
- * @param   pszAddr         The value to convert.
+ * @param   pcszAddr        The value to convert.
+ * @param   ppszNext        Where to store the pointer to the first char
+ *                            following the address. (Optional)
  * @param   pAddr           Where to store the result.
  */
-RTDECL(int) RTNetStrToIPv4Addr(const char *pszAddr, PRTNETADDRIPV4 pAddr);
+RTDECL(int) RTNetStrToIPv4AddrEx(const char *pcszAddr, PRTNETADDRIPV4 pAddr, char **ppszNext);
+
+/**
+ * Parses dotted-decimal IPv4 address into RTNETADDRIPV4 representation.
+ * Leading and trailing whitespace is ignored.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   pcszAddr        The value to convert.
+ * @param   pAddr           Where to store the result.
+ */
+RTDECL(int) RTNetStrToIPv4Addr(const char *pcszAddr, PRTNETADDRIPV4 pAddr);
+
+/**
+ * Parses dotted-decimal IPv4 CIDR notation into RTNETADDRIPV4
+ * representation and prefix length.  Missing prefix specification is
+ * treated as exact address specification (prefix length 32).  Leading
+ * and trailing whitespace is ignored.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   pcszAddr        The value to convert.
+ * @param   pAddr           Where to store the address.
+ * @param   piPrefix        Where to store the prefix length;
+ */
+RTDECL(int) RTNetStrToIPv4Cidr(const char *pcszAddr, PRTNETADDRIPV4 pAddr, int *piPrefix);
+
+/**
+ * Verifies that RTNETADDRIPV4 is a valid contiguous netmask and
+ * computes its prefix length.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   pMask           The netmask to verify and convert.
+ * @param   piPrefix        Where to store the prefix length. (Optional)
+ */
+RTDECL(int) RTNetMaskToPrefixIPv4(PCRTNETADDRIPV4 pMask, int *piPrefix);
+
+/**
+ * Computes netmask corresponding to the prefix length.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   iPrefix         The prefix to convert.
+ * @param   pMask           Where to store the netmask.
+ */
+RTDECL(int) RTNetPrefixToMaskIPv4(int iPrefix, PRTNETADDRIPV4 pMask);
 
 
 /**
@@ -86,6 +159,65 @@ typedef RTNETADDRIPV6 const *PCRTNETADDRIPV6;
  */
 RTDECL(bool) RTNetIsIPv6AddrStr(const char *pszAddress);
 
+/**
+ * Tests if the given string is a wildcard IPv6 address.
+ *
+ * @returns @c true if it is, @c false if not.
+ * @param   pszAddress          String which may be an IPv6 address.
+ */
+RTDECL(bool) RTNetStrIsIPv6AddrAny(const char *pszAddress);
+
+/**
+ * Parses IPv6 address into RTNETADDRIPV6 representation.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   pcszAddr        The value to convert.
+ * @param   ppszNext        Where to store the pointer to the first char
+ *                            following the address. (Optional)
+ * @param   pAddr           Where to store the result.
+ */
+RTDECL(int) RTNetStrToIPv6AddrEx(const char *pcszAddr, PRTNETADDRIPV6 pAddr, char **ppszNext);
+
+/**
+ * Parses IPv6 address into RTNETADDRIPV6 representation.
+ * Leading and trailing whitespace is ignored.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   pcszAddr        The value to convert.
+ * @param   ppszZone        Where to store the pointer to the first char
+ *                            of the zone id.  NULL is stored if there is
+ *                            no zone id.
+ * @param   pAddr           Where to store the result.
+ */
+RTDECL(int) RTNetStrToIPv6Addr(const char *pcszAddr, PRTNETADDRIPV6 pAddr, char **ppszZone);
+
+/**
+ * Verifies that RTNETADDRIPV6 is a valid contiguous netmask and
+ * computes its prefix length.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   pMask           The netmask to verify and convert.
+ * @param   piPrefix        Where to store the prefix length. (Optional)
+ */
+RTDECL(int) RTNetMaskToPrefixIPv6(PCRTNETADDRIPV6 pMask, int *piPrefix);
+
+/**
+ * Computes netmask corresponding to the prefix length.
+ *
+ * @returns VINF_SUCCESS on success, VERR_INVALID_PARAMETER on
+ *          failure.
+ *
+ * @param   iPrefix         The prefix to convert.
+ * @param   pMask           Where to store the netmask.
+ */
+RTDECL(int) RTNetPrefixToMaskIPv6(int iPrefix, PRTNETADDRIPV6 pMask);
+
 
 /**
  * IPX address.
@@ -747,48 +879,71 @@ typedef RTNETICMPV4 *PRTNETICMPV4;
 typedef RTNETICMPV4 const *PCRTNETICMPV4;
 
 
-/** @todo add ICMPv6 when needed. */
+/**
+ * IPv6 ICMP packet header.
+ */
+#pragma pack(1)
+typedef struct RTNETICMPV6HDR
+{
+    /** 00 - The ICMPv6 message type. */
+    uint8_t         icmp6_type;
+    /** 01 - Type specific code that further qualifies the message. */
+    uint8_t         icmp6_code;
+    /** 02 - Checksum of the ICMPv6 message. */
+    uint16_t        icmp6_cksum;
+} RTNETICMPV6HDR;
+#pragma pack()
+AssertCompileSize(RTNETICMPV6HDR, 4);
+/** Pointer to an ICMPv6 packet header. */
+typedef RTNETICMPV6HDR *PRTNETICMPV6HDR;
+/** Pointer to a const ICMP packet header. */
+typedef RTNETICMPV6HDR const *PCRTNETICMPV6HDR;
 
 #define RTNETIPV6_PROT_ICMPV6       (58)
-#define RTNETIPV6_ICMPV6_CODE_0     (0)
-#define RTNETIPV6_ICMP_NS_TYPE      (135)
-#define RTNETIPV6_ICMP_NA_TYPE      (136)
+
+/** @name Internet Control Message Protocol version 6 (ICMPv6) message types.
+ * @{ */
+#define RTNETIPV6_ICMP_TYPE_RS      133
+#define RTNETIPV6_ICMP_TYPE_RA      134
+#define RTNETIPV6_ICMP_TYPE_NS      135
+#define RTNETIPV6_ICMP_TYPE_NA      136
+#define RTNETIPV6_ICMP_TYPE_RDR     137
+/** @} */
+
+/** @name Neighbor Discovery option types
+ * @{ */
 #define RTNETIPV6_ICMP_ND_SLLA_OPT  (1)
 #define RTNETIPV6_ICMP_ND_TLLA_OPT  (2)
-#define RTNETIPV6_ICMP_ND_LLA_LEN   (1)
+/** @} */
 
-/** ICMPv6 ND Source Link Layer Address option */
+/** ICMPv6 ND Source/Target Link Layer Address option */
 #pragma pack(1)
-typedef struct RTNETNDP_SLLA_OPT
+typedef struct RTNETNDP_LLA_OPT
 {
     uint8_t type;
     uint8_t len;
-    RTMAC slla;
-} RTNETNDP_SLLA_OPT;
+    RTMAC lla;
+} RTNETNDP_LLA_OPT;
 #pragma pack()
 
-AssertCompileSize(RTNETNDP_SLLA_OPT, 1+1+6);
+AssertCompileSize(RTNETNDP_LLA_OPT, 1+1+6);
 
-typedef RTNETNDP_SLLA_OPT *PRTNETNDP_SLLA_OPT;
-typedef RTNETNDP_SLLA_OPT const *PCRTNETNDP_SLLA_OPT;
+typedef RTNETNDP_LLA_OPT *PRTNETNDP_LLA_OPT;
+typedef RTNETNDP_LLA_OPT const *PCRTNETNDP_LLA_OPT;
 
 /** ICMPv6 ND Neighbor Sollicitation */
 #pragma pack(1)
 typedef struct RTNETNDP
 {
-    /** ICMPv6 type. */
-    uint8_t icmp6_type;
-    /** ICMPv6 code. */
-    uint8_t icmp6_code;
-    /** ICMPv6 checksum */
-    uint16_t icmp6_cksum;
-    /** reserved */
+    /** 00 - The ICMPv6 header. */
+    RTNETICMPV6HDR Hdr;
+    /** 04 - reserved */
     uint32_t reserved;
-    /** target address */
+    /** 08 - target address */
     RTNETADDRIPV6 target_address;
 } RTNETNDP;
 #pragma pack()
-AssertCompileSize(RTNETNDP, 1+1+2+4+16);
+AssertCompileSize(RTNETNDP, 4+4+16);
 /** Pointer to a NDP ND packet. */
 typedef RTNETNDP *PRTNETNDP;
 /** Pointer to a const NDP NS packet. */
@@ -851,7 +1006,7 @@ typedef struct RTNETARPIPV4
     RTNETADDRIPV4   ar_spa;
     /** The target hardware address. */
     RTMAC           ar_tha;
-    /** The arget protocol address. */
+    /** The target protocol address. */
     RTNETADDRIPV4   ar_tpa;
 } RTNETARPIPV4;
 #pragma pack()
