@@ -1,10 +1,10 @@
-/* $Rev: 108519 $ */
+/* $Rev: 126386 $ */
 /** @file
  * VBoxDrv - The VirtualBox Support Driver - Linux specifics.
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -52,12 +52,7 @@
 #endif
 
 #include <linux/sched.h>
-#ifdef CONFIG_DEVFS_FS
-# include <linux/devfs_fs_kernel.h>
-#endif
-#ifdef CONFIG_VBOXDRV_AS_MISC
-# include <linux/miscdevice.h>
-#endif
+#include <linux/miscdevice.h>
 #ifdef VBOX_WITH_SUSPEND_NOTIFICATION
 # include <linux/platform_device.h>
 #endif
@@ -66,6 +61,8 @@
 # include <asm/msr.h>
 #endif
 
+#include <asm/desc.h>
+
 #include <iprt/asm-amd64-x86.h>
 
 
@@ -79,15 +76,6 @@
 #  endif
 # endif
 
-/* devfs defines */
-#if defined(CONFIG_DEVFS_FS) && !defined(CONFIG_VBOXDRV_AS_MISC)
-# ifdef VBOX_WITH_HARDENING
-#  define VBOX_DEV_FMASK     (S_IWUSR | S_IRUSR)
-# else
-#  define VBOX_DEV_FMASK     (S_IRUGO | S_IWUGO)
-# endif
-#endif /* CONFIG_DEV_FS && !CONFIG_VBOXDEV_AS_MISC */
-
 #ifdef CONFIG_X86_HIGH_ENTRY
 # error "CONFIG_X86_HIGH_ENTRY is not supported by VBoxDrv at this time."
 #endif
@@ -142,17 +130,6 @@ static void VBoxDevRelease(struct device *pDev);
  */
 static SUPDRVDEVEXT         g_DevExt;
 
-#ifndef CONFIG_VBOXDRV_AS_MISC
-/** Module major number for vboxdrv. */
-#define DEVICE_MAJOR_SYS    234
-/** Saved major device number for vboxdrv. */
-static int                  g_iModuleMajorSys;
-/** Module major number for vboxdrvu. */
-#define DEVICE_MAJOR_USR    235
-/** Saved major device number for vboxdrvu. */
-static int                  g_iModuleMajorUsr;
-#endif /* !CONFIG_VBOXDRV_AS_MISC */
-
 /** Module parameter.
  * Not prefixed because the name is used by macros and the end of this file. */
 static int force_async_tsc = 0;
@@ -167,9 +144,9 @@ static int force_async_tsc = 0;
  * Memory for the executable memory heap (in IPRT).
  */
 # ifdef DEBUG
-#  define EXEC_MEMORY_SIZE   6291456    /* 6 MB */
+#  define EXEC_MEMORY_SIZE   8388608    /* 8 MB */
 # else
-#  define EXEC_MEMORY_SIZE   1572864    /* 1.5 MB */
+#  define EXEC_MEMORY_SIZE   2097152    /* 2 MB */
 # endif
 extern uint8_t g_abExecMemory[EXEC_MEMORY_SIZE];
 # ifndef VBOX_WITH_TEXT_MODMEM_HACK
@@ -219,7 +196,6 @@ static struct file_operations gFileOpsVBoxDrvUsr =
 #endif
 };
 
-#ifdef CONFIG_VBOXDRV_AS_MISC
 /** The miscdevice structure for vboxdrv. */
 static struct miscdevice gMiscDeviceSys =
 {
@@ -240,7 +216,6 @@ static struct miscdevice gMiscDeviceUsr =
     devfs_name: DEVICE_NAME_USR,
 # endif
 };
-#endif
 
 
 #ifdef VBOX_WITH_SUSPEND_NOTIFICATION
@@ -334,7 +309,6 @@ static int __init VBoxDrvLinuxInit(void)
      * Check for synchronous/asynchronous TSC mode.
      */
     printk(KERN_DEBUG "vboxdrv: Found %u processor cores\n", (unsigned)RTMpGetOnlineCount());
-#ifdef CONFIG_VBOXDRV_AS_MISC
     rc = misc_register(&gMiscDeviceSys);
     if (rc)
     {
@@ -348,51 +322,6 @@ static int __init VBoxDrvLinuxInit(void)
         misc_deregister(&gMiscDeviceSys);
         return rc;
     }
-#else  /* !CONFIG_VBOXDRV_AS_MISC */
-    /*
-     * Register character devices and save the returned major numbers.
-     */
-    /* /dev/vboxdrv */
-    g_iModuleMajorSys = DEVICE_MAJOR_SYS;
-    rc = register_chrdev((dev_t)g_iModuleMajorSys, DEVICE_NAME_SYS, &gFileOpsVBoxDrvSys);
-    if (rc < 0)
-    {
-        Log(("register_chrdev() failed with rc=%#x for vboxdrv!\n", rc));
-        return rc;
-    }
-    if (DEVICE_MAJOR_SYS != 0)
-        g_iModuleMajorSys = DEVICE_MAJOR_SYS;
-    else
-        g_iModuleMajorSys = rc;
-
-    /* /dev/vboxdrvu */
-    /** @todo Use a minor number of this bugger (not sure if this code is used
-     *        though, so not bothering right now.) */
-    g_iModuleMajorUsr = DEVICE_MAJOR_USR;
-    rc = register_chrdev((dev_t)g_iModuleMajorUsr, DEVICE_NAME_USR, &gFileOpsVBoxDrvUsr);
-    if (rc < 0)
-    {
-        Log(("register_chrdev() failed with rc=%#x for vboxdrv!\n", rc));
-        return rc;
-    }
-    if (DEVICE_MAJOR_USR != 0)
-        g_iModuleMajorUsr = DEVICE_MAJOR_USR;
-    else
-        g_iModuleMajorUsr = rc;
-    rc = 0;
-
-# ifdef CONFIG_DEVFS_FS
-    /*
-     * Register a device entry
-     */
-    if (   devfs_mk_cdev(MKDEV(DEVICE_MAJOR_SYS, 0), S_IFCHR | VBOX_DEV_FMASK, DEVICE_NAME_SYS) != 0
-        || devfs_mk_cdev(MKDEV(DEVICE_MAJOR_USR, 0), S_IFCHR | VBOX_DEV_FMASK, DEVICE_NAME_USR) != 0)
-    {
-        Log(("devfs_register failed!\n"));
-        rc = -EINVAL;
-    }
-# endif
-#endif /* !CONFIG_VBOXDRV_AS_MISC */
     if (!rc)
     {
         /*
@@ -450,20 +379,10 @@ static int __init VBoxDrvLinuxInit(void)
         /*
          * Failed, cleanup and return the error code.
          */
-#if defined(CONFIG_DEVFS_FS) && !defined(CONFIG_VBOXDRV_AS_MISC)
-        devfs_remove(DEVICE_NAME_SYS);
-        devfs_remove(DEVICE_NAME_USR);
-#endif
     }
-#ifdef CONFIG_VBOXDRV_AS_MISC
     misc_deregister(&gMiscDeviceSys);
     misc_deregister(&gMiscDeviceUsr);
     Log(("VBoxDrv::ModuleInit returning %#x (minor:%d & %d)\n", rc, gMiscDeviceSys.minor, gMiscDeviceUsr.minor));
-#else
-    unregister_chrdev(g_iModuleMajorUsr, DEVICE_NAME_USR);
-    unregister_chrdev(g_iModuleMajorSys, DEVICE_NAME_SYS);
-    Log(("VBoxDrv::ModuleInit returning %#x (major:%d & %d)\n", rc, g_iModuleMajorSys, g_iModuleMajorUsr));
-#endif
     return rc;
 }
 
@@ -484,20 +403,8 @@ static void __exit VBoxDrvLinuxUnload(void)
      * I Don't think it's possible to unload a driver which processes have
      * opened, at least we'll blindly assume that here.
      */
-#ifdef CONFIG_VBOXDRV_AS_MISC
     misc_deregister(&gMiscDeviceUsr);
     misc_deregister(&gMiscDeviceSys);
-#else  /* !CONFIG_VBOXDRV_AS_MISC */
-# ifdef CONFIG_DEVFS_FS
-    /*
-     * Unregister a device entry
-     */
-    devfs_remove(DEVICE_NAME_USR);
-    devfs_remove(DEVICE_NAME_SYS);
-# endif /* devfs */
-    unregister_chrdev(g_iModuleMajorUsr, DEVICE_NAME_USR);
-    unregister_chrdev(g_iModuleMajorSys, DEVICE_NAME_SYS);
-#endif /* !CONFIG_VBOXDRV_AS_MISC */
 
     /*
      * Destroy GIP, delete the device extension and terminate IPRT.
@@ -674,21 +581,18 @@ static int VBoxDrvLinuxIOCtl(struct inode *pInode, struct file *pFilp, unsigned
      * Deal with the two high-speed IOCtl that takes it's arguments from
      * the session and iCmd, and only returns a VBox status code.
      */
+    AssertCompile(_IOC_NRSHIFT == 0 && _IOC_NRBITS == 8);
 #ifdef HAVE_UNLOCKED_IOCTL
-    if (RT_LIKELY(   (   uCmd == SUP_IOCTL_FAST_DO_RAW_RUN
-                      || uCmd == SUP_IOCTL_FAST_DO_HM_RUN
-                      || uCmd == SUP_IOCTL_FAST_DO_NOP)
-                  && pSession->fUnrestricted == true))
-        rc = supdrvIOCtlFast(uCmd, ulArg, &g_DevExt, pSession);
+    if (RT_LIKELY(   (unsigned int)(uCmd - SUP_IOCTL_FAST_DO_FIRST) < (unsigned int)32
+                  && pSession->fUnrestricted))
+        rc = supdrvIOCtlFast(uCmd - SUP_IOCTL_FAST_DO_FIRST, ulArg, &g_DevExt, pSession);
     else
         rc = VBoxDrvLinuxIOCtlSlow(pFilp, uCmd, ulArg, pSession);
 #else   /* !HAVE_UNLOCKED_IOCTL */
     unlock_kernel();
-    if (RT_LIKELY(   (   uCmd == SUP_IOCTL_FAST_DO_RAW_RUN
-                      || uCmd == SUP_IOCTL_FAST_DO_HM_RUN
-                      || uCmd == SUP_IOCTL_FAST_DO_NOP)
-                  && pSession->fUnrestricted == true))
-        rc = supdrvIOCtlFast(uCmd, ulArg, &g_DevExt, pSession);
+    if (RT_LIKELY(   (unsigned int)(uCmd - SUP_IOCTL_FAST_DO_FIRST) < (unsigned int)32
+                  && pSession->fUnrestricted))
+        rc = supdrvIOCtlFast(uCmd - SUP_IOCTL_FAST_DO_FIRST, ulArg, &g_DevExt, pSession);
     else
         rc = VBoxDrvLinuxIOCtlSlow(pFilp, uCmd, ulArg, pSession);
     lock_kernel();
@@ -941,9 +845,10 @@ int  VBOXCALL   supdrvOSLdrOpen(PSUPDRVDEVEXT pDevExt, PSUPDRVLDRIMAGE pImage, c
 }
 
 
-int  VBOXCALL   supdrvOSLdrValidatePointer(PSUPDRVDEVEXT pDevExt, PSUPDRVLDRIMAGE pImage, void *pv, const uint8_t *pbImageBits)
+int  VBOXCALL   supdrvOSLdrValidatePointer(PSUPDRVDEVEXT pDevExt, PSUPDRVLDRIMAGE pImage, void *pv,
+                                           const uint8_t *pbImageBits, const char *pszSymbol)
 {
-    NOREF(pDevExt); NOREF(pImage); NOREF(pv); NOREF(pbImageBits);
+    NOREF(pDevExt); NOREF(pImage); NOREF(pv); NOREF(pbImageBits); NOREF(pszSymbol);
     return VERR_NOT_SUPPORTED;
 }
 
@@ -1312,6 +1217,17 @@ void VBOXCALL   supdrvOSLdrNotifyUnloaded(PSUPDRVDEVEXT pDevExt, PSUPDRVLDRIMAGE
 }
 
 
+int  VBOXCALL   supdrvOSLdrQuerySymbol(PSUPDRVDEVEXT pDevExt, PSUPDRVLDRIMAGE pImage,
+                                       const char *pszSymbol, size_t cchSymbol, void **ppvSymbol)
+{
+#ifdef VBOX_WITH_NON_PROD_HACK_FOR_PERF_STACKS
+# error "implement me!"
+#endif
+    RT_NOREF(pDevExt, pImage, pszSymbol, cchSymbol, ppvSymbol);
+    return VERR_WRONG_ORDER;
+}
+
+
 #ifdef SUPDRV_WITH_MSR_PROBER
 
 int VBOXCALL    supdrvOSMsrProberRead(uint32_t uMsr, RTCPUID idCpu, uint64_t *puValue)
@@ -1495,6 +1411,9 @@ SUPR0DECL(uint32_t) SUPR0GetKernelFeatures(void)
 #ifdef CONFIG_PAX_KERNEXEC
     fFlags |= SUPKERNELFEATURES_GDT_READ_ONLY;
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 12, 0)
+    fFlags |= SUPKERNELFEATURES_GDT_NEED_WRITABLE;
+#endif
 #if defined(VBOX_STRICT) || defined(VBOX_WITH_EFLAGS_AC_SET_IN_VBOXDRV)
     fFlags |= SUPKERNELFEATURES_SMAP;
 #elif defined(CONFIG_X86_SMAP)
@@ -1505,6 +1424,17 @@ SUPR0DECL(uint32_t) SUPR0GetKernelFeatures(void)
 }
 
 
+int VBOXCALL    supdrvOSGetCurrentGdtRw(RTHCUINTPTR *pGdtRw)
+{
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 12, 0)
+    *pGdtRw = (RTHCUINTPTR)get_current_gdt_rw();
+    return VINF_SUCCESS;
+#else
+    return VERR_NOT_IMPLEMENTED;
+#endif
+}
+
+
 module_init(VBoxDrvLinuxInit);
 module_exit(VBoxDrvLinuxUnload);
 
