@@ -1,10 +1,10 @@
-/* $Id: VBoxPci-linux.c 136787 2020-04-01 12:44:23Z fbatschu $ */
+/* $Id: VBoxPci-linux.c 126767 2018-11-19 20:39:52Z michael $ */
 /** @file
  * VBoxPci - PCI Driver (Host), Linux Specific Code.
  */
 
 /*
- * Copyright (C) 2011-2020 Oracle Corporation
+ * Copyright (C) 2011-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -66,8 +66,8 @@
 /*********************************************************************************************************************************
 *   Internal Functions                                                                                                           *
 *********************************************************************************************************************************/
-static int  __init VBoxPciLinuxInit(void);
-static void __exit VBoxPciLinuxUnload(void);
+static int  VBoxPciLinuxInit(void);
+static void VBoxPciLinuxUnload(void);
 
 
 /*********************************************************************************************************************************
@@ -372,7 +372,7 @@ static int vboxPciFileWrite(struct file* file, unsigned long long offset, unsign
     mm_segment_t fs_save;
 
     fs_save = get_fs();
-    set_fs(KERNEL_DS);
+    set_fs(get_ds());
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 14, 0)
     ret = kernel_write(file, data, size, &offset);
 #else
@@ -842,27 +842,15 @@ DECLHIDDEN(int) vboxPciOsDevMapRegion(PVBOXRAWPCIINS pIns,
         rcLnx = pci_request_region(pPciDev, iRegion, "vboxpci");
         if (!rcLnx)
         {
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
-            /*
-             * ioremap() defaults to no caching since the 2.6 kernels.
-             * ioremap_nocache() has been removed finally in 5.6-rc1.
-             */
-            RTR0PTR R0PtrMapping = ioremap(pci_resource_start(pPciDev, iRegion),
-                                           pci_resource_len(pPciDev, iRegion));
-#else /* KERNEL_VERSION < 2.6.25 */
             /* For now no caching, try to optimize later. */
             RTR0PTR R0PtrMapping = ioremap_nocache(pci_resource_start(pPciDev, iRegion),
                                                    pci_resource_len(pPciDev, iRegion));
-#endif /* KERNEL_VERSION < 2.6.25 */
+
             if (R0PtrMapping != NIL_RTR0PTR)
                 pIns->aRegionR0Mapping[iRegion] = R0PtrMapping;
             else
             {
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
-                vbpci_printk(KERN_DEBUG, pPciDev, "ioremap() failed\n");
-#else
                 vbpci_printk(KERN_DEBUG, pPciDev, "ioremap_nocache() failed\n");
-#endif
                 pci_release_region(pPciDev, iRegion);
                 rc = VERR_MAP_FAILED;
             }
