@@ -1,4 +1,4 @@
-/* $Id: memuserkernel-r0drv-linux.c 133285 2019-09-11 16:44:07Z paulson $ */
+/* $Id: memuserkernel-r0drv-linux.c 125231 2018-09-21 10:21:22Z bird $ */
 /** @file
  * IPRT - User & Kernel Memory, Ring-0 Driver, Linux.
  */
@@ -66,11 +66,7 @@ RT_EXPORT_SYMBOL(RTR0MemUserCopyTo);
 RTR0DECL(bool) RTR0MemUserIsValidAddr(RTR3PTR R3Ptr)
 {
     IPRT_LINUX_SAVE_EFL_AC();
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 0, 0) || defined(RHEL_81)
-    bool fRc = access_ok((void *)R3Ptr, 1);
-#else
     bool fRc = access_ok(VERIFY_READ, (void *)R3Ptr, 1);
-#endif
     IPRT_LINUX_RESTORE_EFL_AC();
     return fRc;
 }
@@ -86,11 +82,7 @@ RTR0DECL(bool) RTR0MemKernelIsValidAddr(void *pv)
     return (uintptr_t)pv >= PAGE_OFFSET;
 #else
 # error "PORT ME"
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 0, 0) || defined(RHEL_81)
-    return !access_ok(pv, 1);
-#else
     return !access_ok(VERIFY_READ, pv, 1);
-#endif /* LINUX_VERSION_CODE */
 #endif
 }
 RT_EXPORT_SYMBOL(RTR0MemKernelIsValidAddr);
