@@ -1,10 +1,10 @@
-/* $Id: mp-r0drv-linux.c 133319 2019-09-12 13:27:35Z fbatschu $ */
+/* $Id: mp-r0drv-linux.c 125988 2018-10-22 10:09:05Z bird $ */
 /** @file
  * IPRT - Multiprocessor, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2008-2019 Oracle Corporation
+ * Copyright (C) 2008-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -283,15 +283,12 @@ RTDECL(int) RTMpOnAll(PFNRTMPWORKER pfnWorker, void *pvUser1, void *pvUser2)
     if (RTCpuSetCount(&OnlineSet) > 1)
     {
         /* Fire the function on all other CPUs without waiting for completion. */
-# if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 3, 0)
-        smp_call_function(rtmpLinuxAllWrapper, &Args, 0 /* wait */);
-# elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
+# if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
         int rc = smp_call_function(rtmpLinuxAllWrapper, &Args, 0 /* wait */);
-        Assert(!rc); NOREF(rc);
 # else
         int rc = smp_call_function(rtmpLinuxAllWrapper, &Args, 0 /* retry */, 0 /* wait */);
-        Assert(!rc); NOREF(rc);
 # endif
+        Assert(!rc); NOREF(rc);
     }
 #endif
 
@@ -329,6 +326,7 @@ RTDECL(int) RTMpOnOthers(PFNRTMPWORKER pfnWorker, void *pvUser1, void *pvUser2)
 {
 #ifdef CONFIG_SMP
     IPRT_LINUX_SAVE_EFL_AC();
+    int rc;
     RTMPARGS Args;
 
     RTTHREADPREEMPTSTATE PreemptState = RTTHREADPREEMPTSTATE_INITIALIZER;
@@ -339,17 +337,14 @@ RTDECL(int) RTMpOnOthers(PFNRTMPWORKER pfnWorker, void *pvUser1, void *pvUser2)
     Args.cHits = 0;
 
     RTThreadPreemptDisable(&PreemptState);
-# if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 3, 0)
-    smp_call_function(rtmpLinuxWrapper, &Args, 1 /* wait */);
-# elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
-    int rc = smp_call_function(rtmpLinuxWrapper, &Args, 1 /* wait */);
-    Assert(rc == 0); NOREF(rc);
+# if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
+    rc = smp_call_function(rtmpLinuxWrapper, &Args, 1 /* wait */);
 # else /* older kernels */
-    int rc = smp_call_function(rtmpLinuxWrapper, &Args, 0 /* retry */, 1 /* wait */);
-    Assert(rc == 0); NOREF(rc);
+    rc = smp_call_function(rtmpLinuxWrapper, &Args, 0 /* retry */, 1 /* wait */);
 # endif /* older kernels */
     RTThreadPreemptRestore(&PreemptState);
 
+    Assert(rc == 0); NOREF(rc);
     IPRT_LINUX_RESTORE_EFL_AC();
 #else
     RT_NOREF(pfnWorker, pvUser1, pvUser2);
