@@ -1,10 +1,10 @@
-/* $Id: semfastmutex-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
+/* $Id: semfastmutex-r0drv-linux.c 118412 2017-10-17 14:26:02Z bird $ */
 /** @file
  * IPRT - Fast Mutex Semaphores, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,9 +25,9 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include "the-linux-kernel.h"
 #include "internal/iprt.h"
 #include <iprt/semaphore.h>
@@ -42,9 +42,9 @@
 #include "internal/magics.h"
 
 
-/*******************************************************************************
-*   Structures and Typedefs                                                    *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Structures and Typedefs                                                                                                      *
+*********************************************************************************************************************************/
 /**
  * Wrapper for the linux semaphore structure.
  */
@@ -63,6 +63,8 @@ typedef struct RTSEMFASTMUTEXINTERNAL
 
 RTDECL(int)  RTSemFastMutexCreate(PRTSEMFASTMUTEX phFastMtx)
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
     /*
      * Allocate.
      */
@@ -81,6 +83,7 @@ RTDECL(int)  RTSemFastMutexCreate(PRTSEMFASTMUTEX phFastMtx)
 #endif
 
     *phFastMtx = pThis;
+    IPRT_LINUX_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemFastMutexCreate);
@@ -106,6 +109,8 @@ RT_EXPORT_SYMBOL(RTSemFastMutexDestroy);
 
 RTDECL(int)  RTSemFastMutexRequest(RTSEMFASTMUTEX hFastMtx)
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
     /*
      * Validate.
      */
@@ -120,6 +125,8 @@ RTDECL(int)  RTSemFastMutexRequest(RTSEMFASTMUTEX hFastMtx)
     AssertRelease(pThis->Owner == NIL_RTNATIVETHREAD);
     ASMAtomicUoWriteSize(&pThis->Owner, RTThreadNativeSelf());
 #endif
+
+    IPRT_LINUX_RESTORE_EFL_ONLY_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemFastMutexRequest);
@@ -127,6 +134,8 @@ RT_EXPORT_SYMBOL(RTSemFastMutexRequest);
 
 RTDECL(int)  RTSemFastMutexRelease(RTSEMFASTMUTEX hFastMtx)
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
     /*
      * Validate.
      */
@@ -140,6 +149,8 @@ RTDECL(int)  RTSemFastMutexRelease(RTSEMFASTMUTEX hFastMtx)
 #endif
     up(&pThis->Semaphore);
     IPRT_DEBUG_SEMS_STATE(pThis, 'u');
+
+    IPRT_LINUX_RESTORE_EFL_ONLY_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemFastMutexRelease);
