@@ -1,4 +1,4 @@
-/* $Id: the-linux-kernel.h 128696 2019-02-07 15:16:42Z michael $ */
+/* $Id: the-linux-kernel.h 120068 2018-01-04 16:56:53Z pklissne $ */
 /** @file
  * IPRT - Include all necessary headers for the Linux kernel.
  */
@@ -100,6 +100,12 @@
 #include <linux/slab.h>
 #include <linux/time.h>
 #include <linux/sched.h>
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 9, 23) && \
+    LINUX_VERSION_CODE < KERNEL_VERSION(3, 9, 31)
+#include  <linux/splice.h>
+#endif
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 9, 0)
 # include <linux/sched/rt.h>
 #endif
@@ -119,9 +125,6 @@
 # include <linux/cpu.h>
 # include <linux/notifier.h>
 #endif
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0)
-# include <uapi/linux/mman.h>
-#endif
 /* For the basic additions module */
 #include <linux/pci.h>
 #include <linux/delay.h>
