@@ -1,4 +1,4 @@
-/* $Id: thread-r0drv-linux.c 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: thread-r0drv-linux.c 123146 2018-06-21 14:45:13Z bird $ */
 /** @file
  * IPRT - Threads, Ring-0 Driver, Linux.
  */
@@ -164,12 +164,10 @@ RT_EXPORT_SYMBOL(RTThreadPreemptIsPendingTrusty);
 
 RTDECL(bool) RTThreadPreemptIsPossible(void)
 {
-    /** @todo r=ramshankar: What about CONFIG_PREEMPT_VOLUNTARY? That can preempt
-     *        too but does so in voluntarily in explicit preemption points. */
 #ifdef CONFIG_PREEMPT
-    return true;    /* yes, kernel preemption is possible. */
+    return true;    /* Yes, kernel preemption is possible. */
 #else
-    return false;   /* no kernel preemption */
+    return false;   /* No kernel preemption (or CONFIG_PREEMPT_VOLUNTARY). */
 #endif
 }
 RT_EXPORT_SYMBOL(RTThreadPreemptIsPossible);
